% This program solves a simple predator-prey model between rabbits (R) and
% foxes (F) given by:
%
%    R' =  a*R*(1 - b*F)
%    F' = -c*F*(1 - d*R)
%
% Note that is uses GLOBAL variables to pass parameter values onto the
% integration functioin.

clear
rng(0)

%%% Set parameter values.
global a b c d
a = 1;
b = 0.5;
c = 0.1;
d = 0.1;

%%% Compute the equilibrium point.
Rhat = 1/d;
Fhat = 1/b;
fprintf(1,'Equilibrium point:  Rhat = %6.2f   Fhat = %6.2f\n',Rhat,Fhat)

%%% Set initial data:
R0   = 1.1*Rhat;
F0   = 0.9*Fhat;

%%% Solve the ODE:
t_final = 50;
[tt,yy] = ode45('odefun2',[0,t_final],[R0;F0]);
rr = yy(:,1);
ff = yy(:,2);

%%% Draw the phase diagram:
figure(1)
subplot(1,2,1)
hold off
[RR,FF] = meshgrid(linspace(0,20,11),linspace(0,4,11));
quiver(RR,FF,a*RR.*(1 - b*FF),-c*FF.*(1 - d*RR),'k')
xlabel('R')
ylabel('F')
hold on
plot(rr,ff,'m',...
     Rhat,Fhat,'r.',...
     R0,F0,'m.','MarkerSize',30,'LineWidth',2)
 
%%% Draw the solutions as functions of time:
subplot(1,2,2)
plot(tt,rr,'b',...
     tt,ff,'r',...
     [0,0],[R0,F0],'k.',...
     'LineWidth',2,'MarkerSize',30)
legend('R','F')
xlabel('t')